pub struct Integer {
pub val: Integer,
}Fields
val: IntegerTrait Implementations
Sourceimpl<'a> AddAssign<&'a Integer> for Integer
impl<'a> AddAssign<&'a Integer> for Integer
Sourcefn add_assign(&mut self, rhs: &Self)
fn add_assign(&mut self, rhs: &Self)
Performs the
+= operation. Read moreSourceimpl<B> AddAssign<B> for Integer
impl<B> AddAssign<B> for Integer
Sourcefn add_assign(&mut self, rhs: B)
fn add_assign(&mut self, rhs: B)
Performs the
+= operation. Read moreSourceimpl AddAssign for Integer
impl AddAssign for Integer
Sourcefn add_assign(&mut self, rhs: Self)
fn add_assign(&mut self, rhs: Self)
Performs the
+= operation. Read moreSourceimpl ArchimedeanDiv for Integer
impl ArchimedeanDiv for Integer
Sourcefn embed_nat<N: Natural>(n: N) -> Self
fn embed_nat<N: Natural>(n: N) -> Self
Maps a natural number into this structure preserving addition and
using the relevant canonical representation Read more
Sourcefn div_arch(self, rhs: Self) -> Self
fn div_arch(self, rhs: Self) -> Self
the unique integer
n such that n*rhs <= self and (n+1)*rhs > selfSourcefn rem_arch(self, rhs: Self) -> Self
fn rem_arch(self, rhs: Self) -> Self
the remaining difference after dividing by rhs (ie.
self - self.div_arch(rhs)*rhs)Sourcefn div_alg_arch(self, rhs: Self) -> (Self, Self)
fn div_alg_arch(self, rhs: Self) -> (Self, Self)
Sourceimpl Bezout for Integer
impl Bezout for Integer
Sourcefn bezout_with_gcd(self, rhs: Self) -> (Self, Self, Self)
fn bezout_with_gcd(self, rhs: Self) -> (Self, Self, Self)
Computes the GCD and the bezout coefficients
in one function call
Sourcefn bezout_coefficients(self, rhs: Self) -> (Self, Self)
fn bezout_coefficients(self, rhs: Self) -> (Self, Self)
Bezout coefficients of a pair of elements Read more
Sourceimpl CheckedAdd for Integer
impl CheckedAdd for Integer
Sourcefn checked_add(&self, v: &Self) -> Option<Self>
fn checked_add(&self, v: &Self) -> Option<Self>
Adds two numbers, checking for overflow. If overflow happens,
None is
returned.Sourceimpl CheckedDiv for Integer
impl CheckedDiv for Integer
Sourcefn checked_div(&self, v: &Self) -> Option<Self>
fn checked_div(&self, v: &Self) -> Option<Self>
Divides two numbers, checking for underflow, overflow and division by
zero. If any of that happens,
None is returned.Sourceimpl CheckedMul for Integer
impl CheckedMul for Integer
Sourcefn checked_mul(&self, v: &Self) -> Option<Self>
fn checked_mul(&self, v: &Self) -> Option<Self>
Multiplies two numbers, checking for underflow or overflow. If underflow
or overflow happens,
None is returned.Sourceimpl CheckedNeg for Integer
impl CheckedNeg for Integer
Sourcefn checked_neg(&self) -> Option<Self>
fn checked_neg(&self) -> Option<Self>
Negates a number, returning
None for results that can’t be represented, like signed MIN
values that can’t be positive, or non-zero unsigned values that can’t be negative. Read moreSourceimpl CheckedRem for Integer
impl CheckedRem for Integer
Sourcefn checked_rem(&self, v: &Self) -> Option<Self>
fn checked_rem(&self, v: &Self) -> Option<Self>
Finds the remainder of dividing two numbers, checking for underflow, overflow and division
by zero. If any of that happens,
None is returned. Read moreSourceimpl CheckedShl for Integer
impl CheckedShl for Integer
Sourceimpl CheckedShr for Integer
impl CheckedShr for Integer
Sourceimpl CheckedSub for Integer
impl CheckedSub for Integer
Sourcefn checked_sub(&self, v: &Self) -> Option<Self>
fn checked_sub(&self, v: &Self) -> Option<Self>
Subtracts two numbers, checking for underflow. If underflow happens,
None is returned.Sourceimpl ComplexSubset for Integer
impl ComplexSubset for Integer
type Real = Float
type Natural = Integer
type Integer = Integer
Sourcefn as_real(self) -> Self::Real
fn as_real(self) -> Self::Real
Converts
self to a real number, discarding any imaginary component, if complex.Sourcefn as_natural(self) -> Self::Natural
fn as_natural(self) -> Self::Natural
Converts
self to a natural number, truncating when necessary.Sourcefn as_integer(self) -> Self::Integer
fn as_integer(self) -> Self::Integer
Converts
self to an integer, truncating when necessary.Sourcefn floor(self) -> Self
fn floor(self) -> Self
Rounds the real and imaginary components of
self to the closest integer downwardSourcefn ceil(self) -> Self
fn ceil(self) -> Self
Rounds the real and imaginary components of
self to the closest integer upwardSourcefn round(self) -> Self
fn round(self) -> Self
Rounds the real and imaginary components of
self to the closest integerSourcefn trunc(self) -> Self
fn trunc(self) -> Self
Rounds the real and imaginary components of
self by removing the factional partsSourcefn fract(self) -> Self
fn fract(self) -> Self
Removes the integral parts of the real and imaginary components of
selfSourcefn modulus_sqrd(self) -> Self
fn modulus_sqrd(self) -> Self
The square of the complex absolute value of
self Read moreSourceimpl<'a> DivAssign<&'a Integer> for Integer
impl<'a> DivAssign<&'a Integer> for Integer
Sourcefn div_assign(&mut self, rhs: &Self)
fn div_assign(&mut self, rhs: &Self)
Performs the
/= operation. Read moreSourceimpl<B> DivAssign<B> for Integer
impl<B> DivAssign<B> for Integer
Sourcefn div_assign(&mut self, rhs: B)
fn div_assign(&mut self, rhs: B)
Performs the
/= operation. Read moreSourceimpl DivAssign for Integer
impl DivAssign for Integer
Sourcefn div_assign(&mut self, rhs: Self)
fn div_assign(&mut self, rhs: Self)
Performs the
/= operation. Read moreSourceimpl Divisibility for Integer
impl Divisibility for Integer
Sourceimpl EuclideanDiv for Integer
impl EuclideanDiv for Integer
Sourcefn euclid_norm(&self) -> Self::Naturals
fn euclid_norm(&self) -> Self::Naturals
A measure of the “degree” of a given element. Read more
Sourcefn div_euc(self, rhs: Self) -> Self
fn div_euc(self, rhs: Self) -> Self
The quotient from Euclidean division
Sourcefn rem_euc(self, rhs: Self) -> Self
fn rem_euc(self, rhs: Self) -> Self
The remainder from the Euclidean division
Sourceimpl FromPrimitive for Integer
impl FromPrimitive for Integer
Sourcefn from_i64(n: i64) -> Option<Self>
fn from_i64(n: i64) -> Option<Self>
Converts an
i64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u64(n: u64) -> Option<Self>
fn from_u64(n: u64) -> Option<Self>
Converts an
u64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_isize(n: isize) -> Option<Self>
fn from_isize(n: isize) -> Option<Self>
Converts an
isize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i8(n: i8) -> Option<Self>
fn from_i8(n: i8) -> Option<Self>
Converts an
i8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i16(n: i16) -> Option<Self>
fn from_i16(n: i16) -> Option<Self>
Converts an
i16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i32(n: i32) -> Option<Self>
fn from_i32(n: i32) -> Option<Self>
Converts an
i32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i128(n: i128) -> Option<Self>
fn from_i128(n: i128) -> Option<Self>
Converts an
i128 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_usize(n: usize) -> Option<Self>
fn from_usize(n: usize) -> Option<Self>
Converts a
usize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u8(n: u8) -> Option<Self>
fn from_u8(n: u8) -> Option<Self>
Converts an
u8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u16(n: u16) -> Option<Self>
fn from_u16(n: u16) -> Option<Self>
Converts an
u16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u32(n: u32) -> Option<Self>
fn from_u32(n: u32) -> Option<Self>
Converts an
u32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u128(n: u128) -> Option<Self>
fn from_u128(n: u128) -> Option<Self>
Converts an
u128 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourceimpl IntegerSubset for Integer
impl IntegerSubset for Integer
Sourcefn as_unsigned(self) -> Self::Unsigned
fn as_unsigned(self) -> Self::Unsigned
Converts
self into an unsigned integer representation Read moreSourcefn abs_unsigned(self) -> Self::Unsigned
fn abs_unsigned(self) -> Self::Unsigned
Takes the absolute value and converts into an unsigned integer representation Read more
Sourceimpl<'a> MulAssign<&'a Integer> for Integer
impl<'a> MulAssign<&'a Integer> for Integer
Sourcefn mul_assign(&mut self, rhs: &Self)
fn mul_assign(&mut self, rhs: &Self)
Performs the
*= operation. Read moreSourceimpl<B> MulAssign<B> for Integer
impl<B> MulAssign<B> for Integer
Sourcefn mul_assign(&mut self, rhs: B)
fn mul_assign(&mut self, rhs: B)
Performs the
*= operation. Read moreSourceimpl MulAssign for Integer
impl MulAssign for Integer
Sourcefn mul_assign(&mut self, rhs: Self)
fn mul_assign(&mut self, rhs: Self)
Performs the
*= operation. Read moreSourceimpl Ord for Integer
impl Ord for Integer
Sourceimpl PartialOrd for Integer
impl PartialOrd for Integer
Sourceimpl<'a> RemAssign<&'a Integer> for Integer
impl<'a> RemAssign<&'a Integer> for Integer
Sourcefn rem_assign(&mut self, rhs: &Self)
fn rem_assign(&mut self, rhs: &Self)
Performs the
%= operation. Read moreSourceimpl<B> RemAssign<B> for Integer
impl<B> RemAssign<B> for Integer
Sourcefn rem_assign(&mut self, rhs: B)
fn rem_assign(&mut self, rhs: B)
Performs the
%= operation. Read moreSourceimpl RemAssign for Integer
impl RemAssign for Integer
Sourcefn rem_assign(&mut self, rhs: Self)
fn rem_assign(&mut self, rhs: Self)
Performs the
%= operation. Read moreSourceimpl<B> ShlAssign<B> for Integer
impl<B> ShlAssign<B> for Integer
Sourcefn shl_assign(&mut self, rhs: B)
fn shl_assign(&mut self, rhs: B)
Performs the
<<= operation. Read moreSourceimpl<B> ShrAssign<B> for Integer
impl<B> ShrAssign<B> for Integer
Sourcefn shr_assign(&mut self, rhs: B)
fn shr_assign(&mut self, rhs: B)
Performs the
>>= operation. Read moreSourceimpl<'a> SubAssign<&'a Integer> for Integer
impl<'a> SubAssign<&'a Integer> for Integer
Sourcefn sub_assign(&mut self, rhs: &Self)
fn sub_assign(&mut self, rhs: &Self)
Performs the
-= operation. Read moreSourceimpl<B> SubAssign<B> for Integer
impl<B> SubAssign<B> for Integer
Sourcefn sub_assign(&mut self, rhs: B)
fn sub_assign(&mut self, rhs: B)
Performs the
-= operation. Read moreSourceimpl SubAssign for Integer
impl SubAssign for Integer
Sourcefn sub_assign(&mut self, rhs: Self)
fn sub_assign(&mut self, rhs: Self)
Performs the
-= operation. Read moreSourceimpl ToPrimitive for Integer
impl ToPrimitive for Integer
Sourcefn to_i64(&self) -> Option<i64>
fn to_i64(&self) -> Option<i64>
Converts the value of
self to an i64. If the value cannot be
represented by an i64, then None is returned.Sourcefn to_u64(&self) -> Option<u64>
fn to_u64(&self) -> Option<u64>
Converts the value of
self to a u64. If the value cannot be
represented by a u64, then None is returned.Sourcefn to_isize(&self) -> Option<isize>
fn to_isize(&self) -> Option<isize>
Converts the value of
self to an isize. If the value cannot be
represented by an isize, then None is returned.Sourcefn to_i8(&self) -> Option<i8>
fn to_i8(&self) -> Option<i8>
Converts the value of
self to an i8. If the value cannot be
represented by an i8, then None is returned.Sourcefn to_i16(&self) -> Option<i16>
fn to_i16(&self) -> Option<i16>
Converts the value of
self to an i16. If the value cannot be
represented by an i16, then None is returned.Sourcefn to_i32(&self) -> Option<i32>
fn to_i32(&self) -> Option<i32>
Converts the value of
self to an i32. If the value cannot be
represented by an i32, then None is returned.Sourcefn to_i128(&self) -> Option<i128>
fn to_i128(&self) -> Option<i128>
Converts the value of
self to an i128. If the value cannot be
represented by an i128 (i64 under the default implementation), then
None is returned. Read moreSourcefn to_usize(&self) -> Option<usize>
fn to_usize(&self) -> Option<usize>
Converts the value of
self to a usize. If the value cannot be
represented by a usize, then None is returned.Sourcefn to_u8(&self) -> Option<u8>
fn to_u8(&self) -> Option<u8>
Converts the value of
self to a u8. If the value cannot be
represented by a u8, then None is returned.Sourcefn to_u16(&self) -> Option<u16>
fn to_u16(&self) -> Option<u16>
Converts the value of
self to a u16. If the value cannot be
represented by a u16, then None is returned.Sourcefn to_u32(&self) -> Option<u32>
fn to_u32(&self) -> Option<u32>
Converts the value of
self to a u32. If the value cannot be
represented by a u32, then None is returned.Sourcefn to_u128(&self) -> Option<u128>
fn to_u128(&self) -> Option<u128>
Converts the value of
self to a u128. If the value cannot be
represented by a u128 (u64 under the default implementation), then
None is returned. Read moreimpl AddAssociative for Integer
impl AddCommutative for Integer
impl AddOrdered for Integer
impl ArchimedeanProperty for Integer
impl Distributive for Integer
impl Eq for Integer
impl Integer for Integer
impl MulAssociative for Integer
impl MulCommutative for Integer
impl MulOrdered for Integer
impl Natural for Integer
impl NoZeroDivisors for Integer
impl StructuralPartialEq for Integer
impl UniquelyFactorizable for Integer